/* -*-C-*-

$Id: utils.h,v 1.2 2005/03/01 21:26:59 cph Exp $

Copyright 2003,2004 Massachusetts Institute of Technology

This file is part of autonet.

Autonet is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

Autonet is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with autonet; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

*/

#ifndef AUTONET_UTILS_H
#define AUTONET_UTILS_H

extern void run_in_background (const char *);
extern void * xmalloc (unsigned long);
extern void * xrealloc (void *, unsigned long);
extern char * copy_string (const char *);
extern void log_perror (const char *);
extern void log_error (const char *);
extern char * read_line (FILE *);
extern double get_real_time (void);

#endif /* not AUTONET_UTILS_H */
